Class: DebugBar::Default

Inherits:
Base
  • Object
show all
Defined in:
lib/debug-bar/default.rb

Overview

A default DebugBar implementation suitable for use in a Ruby On Rails application layout template.

This, of course, may be customized, typically by creating an initializer file at config/initializers/debug_bar.rb, and populating like so:

DEBUG_BAR = DebugBar::Default.new do |bar|
  bar.add {|b| ['Time', Time.now]}
end

Constant Summary

Constants inherited from Base

Base::TEMPLATE_SEARCH_PATHS

Instance Attribute Summary

Attributes inherited from Base

#callbacks, #recipe_books

Method Summary

Methods inherited from Base

#add_callback, #add_recipe_book, #initialize, #recipe_callback, #recipes, #render

Constructor Details

This class inherits a constructor from DebugBar::Base